=======================
The ``getlino`` package
=======================




    A tool to install and configure Lino on your machine.

    The central project homepage is http://getlino.lino-framework.org

    
